# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ncompare']

package_data = \
{'': ['*']}

install_requires = \
['colorama>=0.4.6,<0.5.0',
 'netCDF4>=1.6.4,<2.0.0',
 'numpy>=1.26.0,<2.0.0',
 'openpyxl>=3.1.2,<4.0.0',
 'xarray>=2023.9.0,<2024.0.0']

entry_points = \
{'console_scripts': ['ncompare = ncompare.console:main']}

setup_kwargs = {
    'name': 'ncompare',
    'version': '1.5.0',
    'description': 'Compare the structure of two NetCDF files at the command line',
    'long_description': '# ncompare\n_____\n[![Available on pypi](https://img.shields.io/pypi/v/ncompare.svg)](https://pypi.org/project/ncompare/)\n[![Contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/nasa/ncompare/issues)\n[![Formatted with black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)\n[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)\n\nCompare the structure of two NetCDF files at the command line.\n`ncompare` generates a view of the matching and non-matching groups and variables between two NetCDF datasets.\n\n\n## Installing\n_____\n### Using pip\n\nInstall the latest version of the package from PyPI using pip:\n```shell\npip install ncompare\n```\n\n### Other methods:\n\nFor local development, one can clone the repository and then use poetry or pip from the local directory:\n\n```shell\ngit clone https://github.com/nasa/ncompare.git\n```\n\n###### (Option A) using poetry:\nii) Follow the instructions for installing `poetry` [here](https://python-poetry.org/docs/).\n\niii) Run ```poetry install``` from the repository directory.\n\n###### (Option B) using pip:\n\nii) Run ```pip install .``` from the repository directory.\n\n## Usage\n_____\n\n```shell\nncompare <netcdf file #1> <netcdf file #2>\n```\n\nFor example:\n\n```shell\nncompare S001G01.nc S001G01_SUBSET.nc -g product -v ozone_profile --report subset_comparison.txt\n```\n\n###### Or, If installed using a `poetry` environment:\n```shell\npoetry run ncompare <netcdf file #1> <netcdf file #2>\n```\n\n**A more complete usage demonstration with example output is shown in\n[this example notebook](https://nasa.github.io/ncompare/ncompare-example-usage.html).**\n\n### Options\n\n- `-h`, `--help`            show this help message and exit\n- `--file-text` [FILE_PATH]: Text file to write output to.\n- `--file-csv` [FILE_PATH]: Comma-separated values (CSV) file to write output to.\n- `--file-xlsx` [FILE_PATH]: Excel file to write output to.\n- `--no-color` : Turn off all colorized output.\n- `--show-attributes` : Include variable attributes in the table that compares variables.\n- `--show-chunks` : Include chunk sizes in the table that compares variables.\n- `-v` (`--comparison_var_name`) [VAR_NAME]: Compare specific values for this variable.\n- `-g` (`--comparison_var_group`) [VAR_GROUP]: Group that contains the `comparison_var_name`.\n- `--column-widths` [WIDTH, WIDTH, WIDTH]: Width, in number of characters, of the three columns in the comparison report\n\n## How to test ncompare locally\n\nIf installed using a `poetry` environment, the tests can be run with:\n```\npoetry run pytest tests\n```\n\n## Motivation\n_____\nThe `cdo` (climate data operators) tool\n[does not support NetCDF4 groups](https://code.mpimet.mpg.de/boards/2/topics/12073).\nMoreover, `nco` operators\' `ncdiff` function computes value differences, but\n--- as far as the developers of this tool are aware ---\n`nco` does not have a simple function to show structural differences between NetCDF4 datasets.\n Note that `h5diff`, provided in the HDF5 software, can also be used to find differences.\nIn comparison to `h5diff`, `ncompare` is written and runnable in Python; `ncompare` provides _aligned_ and\n_colorized_ difference report for quicker assessments of groups, variable names, types, shapes, and attributes;\nand can generate report files formatted for other applications. However, note that\n`h5diff` provides comparison of some otherwise "hidden" hdf5 properties, such as _Netcdf4Dimid or _Netcdf4Coordinates,\nwhich are not currently assessed by `ncompare`.\n\n## Known limitations\n_____\n- `ncompare` uses `xarray` to access the root-level dimensions.\nIn some cases, `xarray` will miss dimensions whose names do not also exist as variable names in the dataset\n  (also known as non-coordinate dimensions).\n- Some underlying HDF5 properties, such as _Netcdf4Dimid or _Netcdf4Coordinates, are not currently assesssed by `ncompare`.\n\n# Notices:\n_____\nCopyright 2023 United States Government as represented by the Administrator of the National Aeronautics and Space Administration.  All Rights Reserved.\n\n### Third-Party Software:\nThis software calls the following third-party software, which is subject to the terms and conditions of its licensor,\nas applicable at the time of licensing. Third-party software is not bundled with this software,\nbut may be available from the licensor.\n\nLicense hyperlinks are provided here for information purposes only:\n\n| item     |                               license                               | link                                                          |\n|:---------|:-------------------------------------------------------------------:|:--------------------------------------------------------------|\n| colorama |                            BSD-3-Clause                             | https://opensource.org/licenses/BSD-3-Clause                  |\n| netCDF4  |                             MIT License                             | https://opensource.org/licenses/MIT                           |\n| numpy    |                            BSD-3-Clause                             | https://opensource.org/licenses/BSD-3-Clause                  |\n| openpyxl |                             MIT License                             | https://opensource.org/licenses/MIT                           |\n| xarray   |                     Apache License, version 2.0                     | https://www.apache.org/licenses/LICENSE-2.0                   |\n| Python   | Standard Library Python Software Foundation (PSF) License Agreement | https://docs.python.org/3/license.html#psf-licenseDisclaimers |\n\n\n### No Warranty:\nTHE SUBJECT SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY OF ANY KIND, EITHER EXPRESSED, IMPLIED,\nOR STATUTORY, INCLUDING, BUT NOT LIMITED TO, ANY WARRANTY THAT THE SUBJECT SOFTWARE WILL CONFORM TO SPECIFICATIONS,\nANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR FREEDOM FROM INFRINGEMENT,\nANY WARRANTY THAT THE SUBJECT SOFTWARE WILL BE ERROR FREE, OR ANY WARRANTY THAT DOCUMENTATION, IF PROVIDED,\nWILL CONFORM TO THE SUBJECT SOFTWARE. THIS AGREEMENT DOES NOT, IN ANY MANNER,\nCONSTITUTE AN ENDORSEMENT BY GOVERNMENT AGENCY OR ANY PRIOR RECIPIENT OF ANY RESULTS, RESULTING DESIGNS, HARDWARE,\nSOFTWARE PRODUCTS OR ANY OTHER APPLICATIONS RESULTING FROM USE OF THE SUBJECT SOFTWARE.\nFURTHER, GOVERNMENT AGENCY DISCLAIMS ALL WARRANTIES AND LIABILITIES REGARDING THIRD-PARTY SOFTWARE,\nIF PRESENT IN THE ORIGINAL SOFTWARE, AND DISTRIBUTES IT "AS IS."\n\n### Waiver and Indemnity:\nRECIPIENT AGREES TO WAIVE ANY AND ALL CLAIMS AGAINST THE UNITED STATES GOVERNMENT,\nITS CONTRACTORS AND SUBCONTRACTORS, AS WELL AS ANY PRIOR RECIPIENT. IF RECIPIENT\'S USE OF THE SUBJECT SOFTWARE RESULTS\nIN ANY LIABILITIES, DEMANDS, DAMAGES, EXPENSES OR LOSSES ARISING FROM SUCH USE, INCLUDING ANY DAMAGES FROM PRODUCTS\nBASED ON, OR RESULTING FROM, RECIPIENT\'S USE OF THE SUBJECT SOFTWARE, RECIPIENT SHALL INDEMNIFY AND HOLD HARMLESS\nTHE UNITED STATES GOVERNMENT, ITS CONTRACTORS AND SUBCONTRACTORS, AS WELL AS ANY PRIOR RECIPIENT,\nTO THE EXTENT PERMITTED BY LAW. RECIPIENT\'S SOLE\nREMEDY FOR ANY SUCH MATTER SHALL BE THE IMMEDIATE, UNILATERAL TERMINATION OF THIS AGREEMENT.\n',
    'author': 'Daniel Kaufman',
    'author_email': 'daniel.kaufman@nasa.gov',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/nasa/ncompare',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<3.13',
}


setup(**setup_kwargs)
